==> mingw-w64-freecad-0.21.2-8.src.tar.zst: FreeCAD-0.21.2/src/App/Resources/translations/App_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="119"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation>Stochează ultima alegere a utilizatorului de a aplica CopyOnChange setup la toate link-urile
care fac referire la același obiect configurabil</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="441"/>
      <source>Unnamed</source>
      <translation>Nedenumit</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="140"/>
      <source>X-axis</source>
      <translation>Axa X</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="141"/>
      <source>Y-axis</source>
      <translation>Axa Y</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>Z-axis</source>
      <translation>Axa Z</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>XY-plane</source>
      <translation>Planul XY</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>XZ-plane</source>
      <translation>Plan XZ</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>YZ-plane</source>
      <translation>YZ-plane</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>Origine</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0rc2-2.src.tar.zst: FreeCAD-1.0rc2/src/App/Resources/translations/App_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="118"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation>Stochează ultima alegere a utilizatorului de a aplica' copierea la modificare înființat la toate link-urile
care fac referire la același obiect configurabil</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="463"/>
      <source>Unnamed</source>
      <translation>Nedenumit</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>X-axis</source>
      <translation>Axa X</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>Y-axis</source>
      <translation>Axa Y</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>Z-axis</source>
      <translation>Axa Z</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>XY-plane</source>
      <translation>Planul XY</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="146"/>
      <source>XZ-plane</source>
      <translation>Plan XZ</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="147"/>
      <source>YZ-plane</source>
      <translation>YZ-plane</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>Origine</translation>
    </message>
  </context>
</TS>
